(*   PEPS dient zur Ausgabe der aktuellen Daten ber den seriellen Port
in den programmierbaren Eprom-Simulator
Zur Ausgabe wird der Druckerport benutzt, es wird folgende
Zuordnung verlangt:
DATA 1     =     Dateneingang des PEPS
DATA 2     =     M0
DATA 3     =     M1
DATA 4     =     Clock

siehe dazu auch   PEPS.DOC    *)

(* Festlegung des Druckerports fr LPT1, wenn LPT2 gewnscht wird,
hier den Wert $278 eintragen                                    *)

CONST LPT1 = $378;

VAR datei : TEXT;
  name : STRING (. 12 .);
  zeile : STRING (. 3 .);
  o, f : INTEGER;
  (* ------------------------------------------------------------------ *)

  PROCEDURE m0;               (* Adresse hochzhlen Modus 0   *)
  BEGIN
    PORT (. lpt1 .) := PORT (. lpt1 .) AND 249
  END;

  (* ------------------------------------------------------------------ *)

  PROCEDURE m1;               (* Daten einschieben  Modus 1   *)
  BEGIN
    PORT (. lpt1 .) := (PORT (. lpt1 .) AND 251) OR 2
  END;

  (* ------------------------------------------------------------------ *)


  PROCEDURE m2;               (* Daten einschreiben Modus 2   *)
  BEGIN
    PORT (. lpt1 .) := (PORT (. lpt1 .) AND 253) OR 4 (*Mit 11111011b verknpft*)
  END;

  (* ------------------------------------------------------------------ *)

  PROCEDURE m3;               (* EPROM simulieren   Modus 3    *)
  BEGIN
    PORT (. lpt1 .) := PORT (. lpt1 .) OR 6 (*Mit 11111011b verknpft*)
  END;

  (* ------------------------------------------------------------------ *)

  PROCEDURE clock;            (* Gibt einen Clockimpuls aus  *)

  BEGIN
    PORT (. lpt1 .) := PORT (. lpt1 .) OR 8;
    PORT (. lpt1 .) := PORT (. lpt1 .) AND 247;

  END;

  (* ------------------------------------------------------------------ *)

  PROCEDURE clockon;
  BEGIN
    PORT (. lpt1 .) := PORT (. lpt1 .) OR 8;
  END;

  (* ------------------------------------------------------------------ *)

  PROCEDURE clockoff;
  BEGIN
    PORT (. lpt1 .) := PORT (. lpt1 .) AND 247;
  END;

  (* ------------------------------------------------------------------ *)

  PROCEDURE setzenull;        (* Setzt Adressen des Peps auf 0 *)

  BEGIN
    m3;
    clock;
  END;

  (* ------------------------------------------------------------------ *)

  PROCEDURE schreibebyte(Wort : BYTE);

  VAR
    bit : BYTE;
    i : BYTE;
    Y : INTEGER;
    PROCEDURE schreibebit;
    BEGIN
      IF bit = 128 THEN PORT (. lpt1 .) := PORT (. lpt1 .) AND 254; (* Hier findet *)
      IF bit = 0 THEN PORT (. lpt1 .) := PORT (. lpt1 .) OR 1; (* u.a. die Inver- *)
    END;                      (* tierung statt *)

  BEGIN
    m1;
    bit := 0;
    FOR y := 0 TO 7 DO        (* Alle 8 Bits ausgeben *)
      BEGIN
        bit := wort AND 128;
        schreibebit;
        clock;
        wort := wort SHL 1;
      END;
    m2;
    clock;
  END;

  (* ------------------------------------------------------------------ *)
  (* ----------  Hier beginnt das Hauptprogramm ----------------------- *)


BEGIN


  WRITELN('Bitte den Namen der Objektdatei angeben');
  READLN(name);
  IF POS('.', name) = 0 THEN
    name := name+'.obj';
  ASSIGN(datei, name);
  RESET(datei);
  clockoff;
  setzenull;
  WHILE NOT EOF(datei) DO BEGIN
    READLN(datei, zeile);
    zeile := ('$'+zeile);

    VAL(zeile, o, f);
    (*         writeln(zeile,'  ',o);  *)
    schreibebyte(o);
    m0;
    clock;
  END;
  m3;
  clockon;
  WRITELN;
  WRITELN('Die Werte der Objektdatei "', name, '" befinden sich nun im');
  WRITELN;
  WRITELN('Epromsimulator PEPS. Das Programm kann durch einen RESET');
  WRITELN;
  WRITELN('des MCS-48-Microcomputers gestartet werden.');
  WRITELN;

END.
